.. currentmodule:: sardana.sardanamanager

:mod:`~sardana.pool.sardanamanager`
=====================================

.. automodule:: sardana.sardanamanager

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`SardanaElementManager`

SardanaElementManager
----------------------

.. inheritance-diagram:: SardanaElementManager
    :parts: 1
    
.. autoclass:: SardanaElementManager
    :inherited-members:
    :members:
    :undoc-members: